@@ -18,6 +18,7 @@
 #include <dcopref.h>
 #include <kmessagebox.h>
 #include <dcopclient.h>
+#include <kcharsets.h>
 
 #include <qvaluevector.h>
 #include <qheader.h>
@@ -26,6 +27,7 @@
 #include "treeview.h"
 #include "../global.h"
 #include "../engine/linkstatus.h"
+#include "../engine/linkfilter.h"
 #include "../cfg/klsconfig.h"
 
 
@@ -44,7 +46,7 @@ TreeView::TreeView(QWidget *parent, const char *name,
     //setFocusPolicy( WheelFocus );
     setRootIsDecorated(KLSConfig::displayTreeView());
     //setResizeMode(QListView::LastColumn);
-    
+
     sub_menu_ = new QPopupMenu(this, "sub_menu_referrers");
     
     connect(this, SIGNAL( rightButtonClicked ( QListViewItem *, const QPoint &, int )),
@@ -53,7 +55,9 @@ TreeView::TreeView(QWidget *parent, const char *name,
 
 
 TreeView::~TreeView()
-{}
+{
+    saveLayout(KLSConfig::self()->config(), "klinkstatus");
+}
 
 void TreeView::setColumns(QStringList const& columns)
 {
@@ -63,8 +67,6 @@ void TreeView::setColumns(QStringList const& columns)
     // resetColumns is called automatically
     for(uint i = 0; i != columns.size(); ++i)
     {
-        setColumnWidthMode(i, Manual);
-
         if(i == 0)
         {
             Q_ASSERT(columns[i] == i18n("URL") && col_url_ == 1);
@@ -80,6 +82,8 @@ void TreeView::setColumns(QStringList const& columns)
             Q_ASSERT(columns[i] == i18n("Label") && col_label_ == 3);
             addColumn(i18n(columns[i])/*, (int)(0.45 * width() - 79)*/);
         }
+
+        setColumnWidthMode(i, QListView::Manual);
     }
 
     setColumnAlignment(col_status_ - 1, Qt::AlignCenter);
@@ -140,6 +144,23 @@ void TreeView::show(ResultView::Status const& status)
     }
 }
 
+void TreeView::show(LinkMatcher link_matcher)
+{
+    QListViewItemIterator it(this);
+    while(it.current())
+    {
+        TreeViewItem* item = myItem(it.current());
+        bool match = link_matcher.matches(*(item->linkStatus()));
+        
+        if(tree_display_)
+            item->setEnabled(match);
+        else
+            item->setVisible(match);
+        
+        ++it;
+    }
+}
+
 void TreeView::showAll()
 {
     QListViewItemIterator it(this);
@@ -324,8 +345,9 @@ void TreeView::loadContextTableMenu(QValueVector<KURL> const& referrers, bool is
         }
         connect(sub_menu_, SIGNAL(activated(int)), this, SLOT(slotEditReferrerWithQuanta(int)));
 
-        context_table_menu_.insertItem(SmallIconSet("fileopen"), i18n("Edit Referrer with Quanta"),
+        context_table_menu_.insertItem(SmallIconSet("edit"), i18n("Edit Referrer with Quanta"),
                                        sub_menu_);
+        context_table_menu_.insertSeparator();
     }
     else
     {
@@ -336,7 +358,7 @@ void TreeView::loadContextTableMenu(QValueVector<KURL> const& referrers, bool is
     context_table_menu_.insertItem(SmallIconSet("fileopen"), i18n("Open URL"),
                                    this, SLOT(slotViewUrlInBrowser()));
 
-    context_table_menu_.insertItem(SmallIconSet("fileopen"), i18n("Open Referrer URL"),
+    context_table_menu_.insertItem(/*SmallIconSet("fileopen"), */i18n("Open Referrer URL"),
                                    this, SLOT(slotViewParentUrlInBrowser()));
 
     context_table_menu_.insertSeparator();
@@ -344,10 +366,10 @@ void TreeView::loadContextTableMenu(QValueVector<KURL> const& referrers, bool is
     context_table_menu_.insertItem(SmallIconSet("editcopy"), i18n("Copy URL"),
                                    this, SLOT(slotCopyUrlToClipboard()));
 
-    context_table_menu_.insertItem(SmallIconSet("editcopy"), i18n("Copy Referrer URL"),
+    context_table_menu_.insertItem(/*SmallIconSet("editcopy"), */i18n("Copy Referrer URL"),
                                    this, SLOT(slotCopyParentUrlToClipboard()));
 
-    context_table_menu_.insertItem(SmallIconSet("editcopy"), i18n("Copy Cell Text"),
+    context_table_menu_.insertItem(/*SmallIconSet("editcopy"), */i18n("Copy Cell Text"),
                                    this, SLOT(slotCopyCellTextToClipboard()));
 }
 
@@ -389,12 +411,7 @@ void TreeViewItem::init(LinkStatus const* linkstatus)
     {
         TreeColumnViewItem item(linkstatus, i + 1);
         column_items_.push_back(item);
-    }
-    for(uint i = 0; i != column_items_.size(); ++i)
-    {
-        TreeColumnViewItem item = column_items_[i];
-
-        setText(item.columnIndex() - 1, item.text(i + 1));
+        setText(item.columnIndex() - 1, KCharsets::resolveEntities(item.text(i + 1)));
         setPixmap(item.columnIndex() - 1, item.pixmap(i + 1));
     }
 }
