@@ -34,12 +34,45 @@
 
 QString QExtFileInfo::lastErrorMsg = "";
 
-/** create a relative short url based in baseURL*/
-KURL QExtFileInfo::toRelative(const KURL& urlToConvert,const KURL& baseURL)
+QString QExtFileInfo::canonicalPath(const QString& path)
 {
+  if (!path.startsWith("/"))
+    return path;
+  bool endsWithSlash = path.endsWith("/");
+  QDir dir(path);
+  if (dir.exists() || QFileInfo(path).exists())
+  {
+    QString s = dir.canonicalPath();
+    if (endsWithSlash)
+      s.append("/");
+    return s;
+  } else
+  {
+    dir.cdUp();
+    QString s = dir.path() + "/";
+    QString s2 = path.mid(s.length());
+    s2 = QExtFileInfo::canonicalPath(s) + s2;
+    return s2;
+  }
+}
+
+/** create a relative short url based in baseURL*/
+KURL QExtFileInfo::toRelative(const KURL& _urlToConvert,const KURL& _baseURL)
+{
+  KURL urlToConvert = _urlToConvert;
+  KURL baseURL = _baseURL;
   KURL resultURL = urlToConvert;
   if (urlToConvert.protocol() == baseURL.protocol())
   {
+    if (urlToConvert.isLocalFile())
+    {
+      QString path = QExtFileInfo::canonicalPath(urlToConvert.path());
+      if (!path.isEmpty())
+        urlToConvert.setPath(path);
+      path = QExtFileInfo::canonicalPath(baseURL.path());
+      if (!path.isEmpty())
+        baseURL.setPath(path);
+    }
     QString path = urlToConvert.path();
     QString basePath = baseURL.path(1);
     if (path.startsWith("/"))
@@ -80,11 +113,20 @@ KURL QExtFileInfo::toRelative(const KURL& urlToConvert,const KURL& baseURL)
   return resultURL;
 }
 /** convert relative filename to absolute */
-KURL QExtFileInfo::toAbsolute(const KURL& urlToConvert,const KURL& baseURL)
+KURL QExtFileInfo::toAbsolute(const KURL& _urlToConvert,const KURL& _baseURL)
 {
+  KURL urlToConvert = _urlToConvert;
+  KURL baseURL = _baseURL;
   KURL resultURL = urlToConvert;
+  
   if (urlToConvert.protocol() == baseURL.protocol() && !urlToConvert.path().startsWith("/"))
   {
+    if (urlToConvert.isLocalFile())
+    {
+      QString path = QExtFileInfo::canonicalPath(baseURL.path());
+      if (!path.isEmpty())
+        baseURL.setPath(path);
+    }
     int pos;
     QString cutname = urlToConvert.path();
     QString cutdir = baseURL.path(1);
@@ -140,17 +182,17 @@ bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
   KURL dir2;
   KURL dir1 = path;
   dir1.setPath("/");
-  if (!exists(dir1, window))
+  if (!exists(dir1, false, window))
   {
     return false; //the root is not accessible, possible wrong username/password supplied
   }
-  while (!exists(path, window) && dir2.path() != path.path())
+  while (!exists(path, false, window) && dir2.path() != path.path())
   {
     dir1 = path;
     dir2 = path;
 
     dir1=cdUp(dir1);
-    while (!exists(dir1, window) && dir1.path() != "/")
+    while (!exists(dir1, false, window) && dir1.path() != "/")
     {
       dir1 = cdUp(dir1);
       dir2 = cdUp(dir2);
@@ -162,7 +204,7 @@ bool QExtFileInfo::createDir(const KURL& path, QWidget *window)
       break;
     i++;
   }
- result = exists(path, window);
+ result = exists(path, false, window);
  return result;
 }
 
@@ -198,20 +240,20 @@ KURL QExtFileInfo::home()
 }
 
 
-bool QExtFileInfo::exists(const KURL& a_url, QWidget *window)
+bool QExtFileInfo::exists(const KURL& a_url, bool readingOnly, QWidget *window)
 {
 // Andras: Don't use it now, as it brings up an extra dialog and need manual
 // intervention when usign fish
 // return KIO::NetAccess::exists(a_url, false);
 
 // No dialog when stating.
- if ( a_url.isLocalFile() )
+ if (a_url.isLocalFile())
  {
-    return QFile::exists( a_url.path() );
+   return QFile::exists(a_url.path());
  } else
  {
-  QExtFileInfo internalFileInfo;
-  return internalFileInfo.internalExists(a_url, window);
+   QExtFileInfo internalFileInfo;
+   return internalFileInfo.internalExists(a_url, readingOnly, window);
  }
 }
 
@@ -230,7 +272,7 @@ KURL::List QExtFileInfo::allFilesInternal(const KURL& startURL, const QString& m
     return allLocalFiles(startURL.path(-1), mask);
 
   dirListItems.clear();
-  if (internalExists(startURL, window))
+  if (internalExists(startURL, true, window))
   {
     lstFilters.setAutoDelete(true);
     lstFilters.clear();
@@ -268,7 +310,7 @@ QDict<KFileItem> QExtFileInfo::allFilesDetailedInternal(const KURL& startURL, co
   detailedDirListItems.setAutoDelete(true);
   detailedDirListItems.clear();
   detailedDirListItems.setAutoDelete(false);
-  if (internalExists(startURL, window))
+  if (internalExists(startURL, true, window))
   {
     lstFilters.setAutoDelete(true);
     lstFilters.clear();
@@ -305,9 +347,17 @@ KURL::List QExtFileInfo::allLocalFiles(const QString& startPath, const QString&
   QDir d(startPath, mask);
   QStringList l = d.entryList();
   QStringList::ConstIterator end = l.constEnd();
+  QString path;
   for (QStringList::ConstIterator it = l.constBegin(); it != end; ++it)
   {
-    list.append(KURL::fromPathOrURL(startPath + "/" + (*it)));
+    path = *it;
+    if (path != "." && path != "..")
+    {
+      path = startPath + "/" + path;
+      if (QFileInfo(path).isDir())
+        path.append("/");
+      list.append(KURL::fromPathOrURL(path));
+    }
   }
   l = d.entryList("*", QDir::Dirs);
   end = l.constEnd();
@@ -322,7 +372,7 @@ KURL::List QExtFileInfo::allLocalFiles(const QString& startPath, const QString&
 
 //Some hackery from KIO::NetAccess as they do not do exactly what we want
 /* return true if the url exists*/
-bool QExtFileInfo::internalExists(const KURL& url, QWidget *window)
+bool QExtFileInfo::internalExists(const KURL& url, bool readingOnly, QWidget *window)
 {
   bJobOK = true;
   KURL url2 = url;
@@ -331,7 +381,7 @@ bool QExtFileInfo::internalExists(const KURL& url, QWidget *window)
   KIO::StatJob * job = KIO::stat(url2, false);
   job->setWindow(window);
   job->setDetails(0);
-  job->setSide(false); //check the url for writing
+  job->setSide(readingOnly); 
   connect( job, SIGNAL( result (KIO::Job *) ),
            this, SLOT( slotResult (KIO::Job *) ) );
 
