@@ -260,7 +260,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
   QValueList<TableNode> tableRowTags;
   QValueVector< QValueVector<TableNode> > mergeMatrix;
   mergeMatrix.resize(pInitialTableSize);
-  for (uint i=0; i<pInitialTableSize; i++)
+  for (uint i = 0; i < pInitialTableSize; i++)
     mergeMatrix[i].resize(pInitialTableSize);
   TableNode tableNode;
   Node *n = node;
@@ -386,7 +386,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
       nRow++;
       if ((uint)nRow >= mergeMatrix.size()) {  // Check if there are enough rows in mergeMatriz
         mergeMatrix.resize(2 * mergeMatrix.size());
-        for (uint i=mergeMatrix.size() / 2; i<mergeMatrix.size(); i++)
+        for (uint i = mergeMatrix.size() / 2; i < mergeMatrix.size(); i++)
           mergeMatrix[i].resize(mergeMatrix[0].size());
       }
 
@@ -403,15 +403,38 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
       if (countRows)
       {
         maxCol = (nCol > maxCol) ? nCol : maxCol;
-        for (int i = 0; i < maxCol - nCol; i++)
+        maxCol = (maxCol == 0) ? 1 : maxCol;
+        for (int col = nCol; col < maxCol; col++)
         {
-          tableNode.node = new Node(0L);
-          newNum++;
-          tableNode.node->tag = new Tag();
-          tableNode.node->tag->setDtd(m_dtd);
-          tableNode.node->tag->parse("<td>", m_write);
-          tableNode.merged = false;
-          tableRowTags.append(tableNode);
+          if (mergeMatrix[nRow - 1][col].node != 0L) {
+            if (m_colSpin->value() < col)
+                m_colSpin->setValue(col);
+            TableNode tableN = mergeMatrix[nRow - 1][col];
+            Node *n = tableN.node;
+            setCellText(m_dataTable, nRow - 1, col, i18n("Merged with (%1, %2).").arg(tableN.mergedRow + 1).arg(tableN.mergedCol + 1));
+            m_dataTable->item(nRow-1, col)->setEnabled(false);
+            tableNode.node = new Node(0L);
+            tableNode.node->tag = new Tag(*(n->tag));
+            configureCell(nRow-1,  col, tableNode.node);
+            newNum++;
+            tableNode.merged = true;
+            tableNode.mergedRow = tableN.mergedRow;
+            tableNode.mergedCol = tableN.mergedCol;
+            tableRowTags.append(tableNode);
+            if ((uint)nCol >= mergeMatrix[0].size())  // Check if there are enough cols
+              for (uint i=0; i<mergeMatrix.size(); i++)
+                mergeMatrix[i].resize(2 * mergeMatrix[i].size());
+  
+          } else
+          {
+            tableNode.node = new Node(0L);
+            newNum++;
+            tableNode.node->tag = new Tag();
+            tableNode.node->tag->setDtd(m_dtd);
+            tableNode.node->tag->parse("<td>", m_write);
+            tableNode.merged = false;
+            tableRowTags.append(tableNode);
+          }
         }
         if (!tableRowTags.isEmpty())
           m_tableTags->append(tableRowTags);
@@ -432,7 +455,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
           m_dataTable->item(nRow-1, col)->setEnabled(false);
           tableNode.node = new Node(0L);
           tableNode.node->tag = new Tag(*(n->tag));
-	  configureCell(nRow-1,  col, tableNode.node);
+          configureCell(nRow-1,  col, tableNode.node);
           newNum++;
           tableNode.merged = true;
           tableNode.mergedRow = tableN.mergedRow;
@@ -441,7 +464,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
           col++;
           nCol++;
           if ((uint)nCol >= mergeMatrix[0].size())  // Check if there are enough cols
-            for (uint i=0; i<mergeMatrix.size(); i++)
+            for (uint i = 0; i < mergeMatrix.size(); i++)
               mergeMatrix[i].resize(2 * mergeMatrix[i].size());
 
         }
@@ -454,7 +477,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
           setCellText(m_dataTable, nRow - 1, nCol - 1, tagContent(n));
           tableNode.node = new Node(0L);
           tableNode.node->tag = new Tag(*(n->tag));
-	  configureCell(nRow-1,  col, tableNode.node);
+	        configureCell(nRow-1,  col, tableNode.node);
           newNum++;
           tableNode.merged = false;
           tableRowTags.append(tableNode);
@@ -477,7 +500,7 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
               m_dataTable->item(nRow-1, lastCol + i)->setEnabled(false);
               tableNode.node = new Node(0L);
               tableNode.node->tag = new Tag(*(n->tag));
-	      configureCell(nRow-1,  col, tableNode.node);
+              configureCell(nRow-1,  col, tableNode.node);
               newNum++;
               tableNode.merged = true;
               tableNode.mergedRow = nRow - 1;
@@ -497,12 +520,12 @@ bool TableEditor::setTableArea( int bLine, int bCol, int eLine, int eCol, Parser
             lastCol--;
             // Check if there are enough columns in mergeMatriz
             if ((uint)(lastCol + colValue) >= mergeMatrix[0].size())
-              for (uint i=0; i<mergeMatrix.size(); i++)
+              for (uint i = 0; i < mergeMatrix.size(); i++)
                 mergeMatrix[i].resize(2 * mergeMatrix[i].size());
             // Check if there are enough rows in mergeMatriz
             if ((uint)(nRow + rowValue) >= mergeMatrix.size()) {
               mergeMatrix.resize(2 * mergeMatrix.size());
-              for (uint i=mergeMatrix.size() / 2; i<mergeMatrix.size(); i++)
+              for (uint i = mergeMatrix.size() / 2; i < mergeMatrix.size(); i++)
                 mergeMatrix[i].resize(mergeMatrix[0].size());
             }
 
@@ -874,17 +897,49 @@ void TableEditor::slotRemoveRow()
 {
   if (m_row == -1)
     m_row = m_dataTable->numRows() - 1;
-  QValueList<TableNode>::Iterator it = m_tableRows->at(m_row);
-  delete (*it).node;
-  newNum--;
-  m_tableRows->erase(it);
+  int i = 0;
+  int j = 0;
+  for (QValueList<QValueList<TableNode> >::Iterator it = m_tableTags->begin(); it != m_tableTags->end(); ++it) {
+      j = 0;
+      for (QValueList<TableNode>::Iterator it2 = (*it).begin(); it2 != (*it).end(); ++it2) {
+        if ((*it2).merged && (*it2).mergedRow == m_row) {
+          (*it2).merged = false;
+          setCellText(m_dataTable, i, j, tagContent((*it2).node));
+          m_dataTable->item(i, j)->setEnabled(true);
+          (*it2).node->tag->deleteAttribute("colspan");
+          (*it2).node->tag->deleteAttribute("rowspan");
+        }
+        j++;
+      }
+      i++;
+  }
+  QValueList<TableNode*> updatedMainNodes;
   QValueList<QValueList<TableNode> >::Iterator it2 = m_tableTags->at(m_row);
   for (QValueList<TableNode>::Iterator it3 = (*it2).begin(); it3 != (*it2).end(); ++it3) {
+    if ((*it3).merged)
+    {
+      TableNode *mainTableNode = &((*m_tableTags)[(*it3).mergedRow][(*it3).mergedCol]);
+      if (mainTableNode->node && !updatedMainNodes.contains(mainTableNode))
+      {
+        int rowspan =  mainTableNode->node->tag->attributeValue("rowspan", true).toInt();
+        rowspan--;
+        if (rowspan > 1)
+          mainTableNode->node->tag->editAttribute("rowspan", QString("%1").arg(rowspan));
+        else
+          mainTableNode->node->tag->deleteAttribute("rowspan");
+        updatedMainNodes.append(mainTableNode);
+      }
+    }
     delete (*it3).node;
+    (*it3).node = 0L;
     newNum--;
   }
   m_tableTags->erase(it2);
   m_dataTable->removeRow(m_row);
+  QValueList<TableNode>::Iterator it = m_tableRows->at(m_row);
+  delete (*it).node;
+  newNum--;
+  m_tableRows->erase(it);
   m_rowSpin->setValue(m_dataTable->numRows());
 }
 
@@ -900,6 +955,8 @@ void TableEditor::slotRemoveCol()
           (*it2).merged = false;
           setCellText(m_dataTable, i, j, tagContent((*it2).node));
           m_dataTable->item(i, j)->setEnabled(true);
+          (*it2).node->tag->deleteAttribute("colspan");
+          (*it2).node->tag->deleteAttribute("rowspan");
         }
         j++;
       }
@@ -907,8 +964,23 @@ void TableEditor::slotRemoveCol()
   }
   if (m_col == -1)
     m_col = m_dataTable->numCols() - 1;
+  QValueList<TableNode*> updatedMainNodes;
   for (QValueList<QValueList<TableNode> >::Iterator it = m_tableTags->begin(); it != m_tableTags->end(); ++it) {
     QValueList<TableNode>::Iterator it2 = (*it).at(m_col);
+    if ((*it2).merged)
+    {
+      TableNode *mainTableNode = &((*m_tableTags)[(*it2).mergedRow][(*it2).mergedCol]);
+      if (mainTableNode->node && !updatedMainNodes.contains(mainTableNode))
+      {
+        int colspan = mainTableNode->node->tag->attributeValue("colspan", true).toInt();
+        colspan--;
+        if (colspan > 1)
+          mainTableNode->node->tag->editAttribute("colspan", QString("%1").arg(colspan));
+        else
+          mainTableNode->node->tag->deleteAttribute("colspan");
+        updatedMainNodes.append(mainTableNode);
+      }
+    }
     delete (*it2).node;
     newNum--;
     (*it).erase(it2);
@@ -981,14 +1053,17 @@ void TableEditor::slotMergeCells()
   lCol = selection.leftCol();
   rCol = selection.rightCol();
   TableNode *mainTableNode = &((*m_tableTags)[tRow][lCol]);
-  mainTableNode->node->tag->editAttribute("colspan", QString("%1").arg(rCol - lCol + 1));
-  mainTableNode->node->tag->editAttribute("rowSpan", QString("%1").arg(bRow - tRow + 1));
+  if (rCol - lCol > 0)
+    mainTableNode->node->tag->editAttribute("colspan", QString("%1").arg(rCol - lCol + 1));
+  if (bRow - tRow > 0)
+    mainTableNode->node->tag->editAttribute("rowspan", QString("%1").arg(bRow - tRow + 1));
   for (int i = 0; i < bRow - tRow + 1; i++)
     for (int j = 0; j < rCol - lCol + 1; j++) {
       if (i != 0 || j != 0) {
         setCellText(m_dataTable, tRow + i, lCol + j, i18n("Merged with (%1, %2).").arg(tRow + 1).arg(lCol + 1));
         m_dataTable->item(tRow + i, lCol + j)->setEnabled(false);
         TableNode *tableNode = &((*m_tableTags)[tRow + i][lCol + j]);
+        delete tableNode->node;
         tableNode->node = new Node(0L);
         newNum++;
         tableNode->node->tag = new Tag(*(mainTableNode->node->tag));
