@@ -266,7 +266,7 @@ void ActionConfigDialog::slotSelectionChanged(QListViewItem *item)
   if (currentAction && currentAction->inherits("TagAction"))
   {
     if ( buttonApply->isEnabled() &&
-         KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?")) == KMessageBox::Yes )
+         KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), QString::null, KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes )
     {
       saveCurrentAction();
     }
@@ -658,7 +658,7 @@ void ActionConfigDialog::saveCurrentAction()
         if (listItem)
         {
           QListViewItem *after = listItem->firstChild();
-          while ( after && after->nextSibling() && after->nextSibling()->depth()!=0 )
+          while ( after && (!after->nextSibling() || (after->nextSibling() && after->nextSibling()->depth()!=0 ) ))
           {
             if (after->text(2) == currentAction->name())
             {
@@ -700,17 +700,23 @@ void ActionConfigDialog::slotShortcutCaptured(const KShortcut &shortcut)
     shortcutText2 = shortcutText.mid(pos + 1);
     shortcutText = shortcutText.left(pos);
   }
+  QString s = shortcutText;
+  s.replace('+', "\\+");
+  QRegExp shortcutRx("\\(" + s + "\\)|" + s + "$|" + s + ";");
+  s = shortcutText2;
+  s.replace('+', "\\+");
+  QRegExp shortcutRx2("\\(" + s + "\\)|" + s + "$|" + s + ";");
   QString global;
 //check for conflicting global shortcuts
   QMap<QString, QString>::Iterator it;
   for ( it = globalShortcuts.begin(); it != globalShortcuts.end(); ++it )
   {
-    if (it.data().contains(shortcutText))
+    if (it.data().contains(shortcutRx))
     {
       global = it.key();
       break;
     }
-    if (!shortcutText2.isEmpty() && it.data().contains(shortcutText2))
+    if (!shortcutText2.isEmpty() && it.data().contains(shortcutRx2))
     {
       shortcutText = shortcutText2;
       global = it.key();
@@ -727,12 +733,12 @@ void ActionConfigDialog::slotShortcutCaptured(const KShortcut &shortcut)
         for (uint i = 0; i < ac->count(); i++)
         {
           KAction *action = ac->action(i);
-          if (action != currentAction && action->shortcut().toString().contains(shortcutText))
+          if (action != currentAction && action->shortcut().toString().contains(shortcutRx))
           {
             global = action->text();
             break;
           }
-          if (!shortcutText2.isEmpty() && action != currentAction &&  action->shortcut().toString().contains(shortcutText))
+          if (!shortcutText2.isEmpty() && action != currentAction &&  action->shortcut().toString().contains(shortcutRx))
           {
             shortcutText = shortcutText2;
             global = action->text();
@@ -769,7 +775,7 @@ void ActionConfigDialog::accept()
 
 void ActionConfigDialog::reject()
 {
-  if (buttonApply->isEnabled() && KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?")) == KMessageBox::Yes  )
+  if (buttonApply->isEnabled() && KMessageBox::questionYesNo(this, i18n("Do you want to save the changes made to this action?"), QString::null, KStdGuiItem::save(), KStdGuiItem::discard()) == KMessageBox::Yes  )
       saveCurrentAction();
   ActionConfigDialogS::reject();
 }
@@ -781,16 +787,15 @@ void ActionConfigDialog::slotNewAction()
   el.setAttribute( "name", "user_"+KApplication::randomString(10) );
   el.setAttribute( "icon", "ball" );
 
-  currentAction = new TagAction(&el, m_mainWindow->actionCollection());
-#if KDE_IS_VERSION(3,2,90)
-    //add the actions to every toolbar xmlguiclient
-    QDictIterator<ToolbarEntry> it(m_toolbarList);
-    while (it.current())
-    {
-      it.current()->guiClient->actionCollection()->insert(currentAction);
-      ++it;
-    }
-#endif
+  currentAction = new TagAction(&el, m_mainWindow);
+
+  //add the actions to every toolbar xmlguiclient
+  QDictIterator<ToolbarEntry> it(m_toolbarList);
+  while (it.current())
+  {
+    it.current()->guiClient->actionCollection()->insert(currentAction);
+    ++it;
+  }
 
   selectedShortcut = KShortcut();
   static_cast<TagAction*>(currentAction)->setModified(true);
@@ -873,10 +878,10 @@ void ActionConfigDialog::slotAddContainerToolbar()
 
   if (lst.count() > 0)
   {
-    bool ok = FALSE;
+    bool ok = false;
     QString res = KInputDialog::getItem(
                     i18n( "Add Action to Toolbar" ),
-                    i18n( "Please select a toolbar:" ), lst, 0, FALSE, &ok, this );
+                    i18n( "Please select a toolbar:" ), lst, 0, false, &ok, this );
 
     if (ok)
     {
