@@ -58,11 +58,12 @@ DTEPEditDlg::~DTEPEditDlg()
 
 void DTEPEditDlg::slotFamilyChanged(int family)
 {
-  m_family = family;
-  if (m_family == 0)
+  if (family == 0 && m_family != 0)
     tabWidget->insertTab(m_pagesWidget, i18n("&Pages"), 1);
   else
+  if (family == 1)
    tabWidget->removePage(m_pagesWidget);
+  m_family = family;
 }
 
 void DTEPEditDlg::init()
@@ -201,7 +202,7 @@ void DTEPEditDlg::saveResult()
   {
     if (f.exists())
     {
-      if (KMessageBox::questionYesNo(this, i18n("<qt>The file <b>%1</b> is not writable.<br>Do you want to save the configuration to a different file?</qt>").arg(f.filePath()),i18n("Save As")) == KMessageBox::Yes)
+      if (KMessageBox::questionYesNo(this, i18n("<qt>The file <b>%1</b> is not writable.<br>Do you want to save the configuration to a different file?</qt>").arg(f.filePath()),i18n("Save As"),i18n("Save to Different File"), i18n("Do Not Save")) == KMessageBox::Yes)
       {
         targetFile = KFileDialog::getSaveFileName(locateLocal("data", resourceDir + "dtep/description.rc"), i18n("*.rc|DTEP Description"), this, i18n("Save Description As"));
       } else
