@@ -42,6 +42,9 @@
 #include <kurlrequester.h>
 #include <kurlrequesterdlg.h>
 
+#include <ktexteditor/markinterface.h>
+#include <ktexteditor/viewcursorinterface.h>
+
 // application headers
 #include "copyto.h"
 #include "document.h"
@@ -157,11 +160,13 @@ void Project::insertFile(const KURL& nameURL, bool repaint )
 }
 
 
-void Project::readConfig (KConfig *config)
+void Project::readConfig(KConfig *config)
 {
   d->config = config;
-
-  config->setGroup  ("Projects");
+  config->setGroup("General Options");
+  int maxRecentItems = config->readNumEntry("Recent Files Limit", 32);
+  d->m_projectRecent->setMaxItems(maxRecentItems);
+  config->setGroup ("Projects");
   d->m_projectRecent->loadEntries(config, "RecentProjects");
 }
 
@@ -228,7 +233,10 @@ void Project::loadLastProject(bool reload)
 
   if ( reload && (!urlPath.isEmpty() && url.isValid()))
   {
-    d->loadProject( url );
+    if (!d->loadProject(url))
+    {
+      d->config->deleteEntry("Last Project");
+    }
   }
   d->config->sync();
 }
@@ -243,7 +251,7 @@ void Project::slotOpenProject(const KURL &url)
   kdDebug(24000) << "Open recent project: " << url <<endl;
   if ( !url.isEmpty() )
   {
-    if ( !QExtFileInfo::exists(url, d->m_mainWindow) )
+    if ( !QExtFileInfo::exists(url, true, d->m_mainWindow) )
     {
       emit hideSplash();
       if (KMessageBox::questionYesNo(d->m_mainWindow,
@@ -845,19 +853,19 @@ void Project::slotUpload()
   if (! ViewManager::ref()->saveAll())
     return;
 
-  ProjectUpload *dlg = new ProjectUpload(KURL(), false, false, i18n("Upload project items..."));
+  ProjectUpload *dlg = new ProjectUpload(KURL(), "", false, false, false, i18n("Upload project items..."));
   connect(dlg, SIGNAL(eventHappened(const QString&, const QString&, const QString& )), this, SIGNAL(eventHappened(const QString&, const QString&, const QString& )));
   dlg->show();
 }
 
-void Project::slotUploadURL(const KURL& urlToUpload, bool quickUpload)
+void Project::slotUploadURL(const KURL& urlToUpload, const QString& profileName, bool quickUpload, bool markOnly)
 {
   if (!ViewManager::ref()->saveAll())
     return;
 
   KURL url = QExtFileInfo::toRelative( urlToUpload, d->baseURL);
 
-  ProjectUpload *dlg = new ProjectUpload(url, false, quickUpload, i18n("Upload project items..."));
+  ProjectUpload *dlg = new ProjectUpload(url, profileName, false, quickUpload, markOnly, i18n("Upload project items..."));
   connect(dlg, SIGNAL(eventHappened(const QString&, const QString&, const QString& )), this, SIGNAL(eventHappened(const QString&, const QString&, const QString& )));
   dlg->show();
 }
@@ -1055,6 +1063,10 @@ bool Project::hasProject()
   return !d->projectName.isNull();
 }
 
+QString Project::projectName()
+{
+  return d->projectName;
+}
 
 const QString& Project::defaultDTD()
 {
@@ -1233,7 +1245,9 @@ bool Project::queryClose()
   {
     emit eventHappened("before_project_close", d->baseURL.url(), QString::null);
     d->config->setGroup("Projects");
-    d->config->writePathEntry("Last Project", d->projectURL.url());
+    KURL url = d->projectURL.url();
+    url.setPass("");
+    d->config->writePathEntry("Last Project", url.url());
     canExit = d->uploadProjectFile();
     if (! canExit)
     {
@@ -1320,5 +1334,68 @@ void Project::saveBookmarks(const KURL &url, KTextEditor::MarkInterface *markIf)
   }
 }
 
+void Project::loadCursorPosition(const KURL &url, KTextEditor::ViewCursorInterface *viewCursorIf)
+{
+  if (!viewCursorIf || !hasProject() || !contains(url))
+    return;
+  QDomNodeList nl = d->m_sessionDom.elementsByTagName("item");
+  QDomElement el;
+  KURL u = QExtFileInfo::toRelative(url, d->baseURL);
+  for ( uint i = 0; i < nl.count(); i++ )
+  {
+    el = nl.item(i).toElement();
+    if ( el.attribute("url") == QuantaCommon::qUrl(u) )
+    {
+      QString s = el.attribute("line");      
+      uint line, col;
+      bool ok;
+      line = s.toUInt(&ok, 10);
+      if (ok)
+      {
+        s = el.attribute("column");
+        col = s.toUInt(&ok, 10);
+        if (ok)
+         viewCursorIf->setCursorPositionReal(line, col);
+      }
+    }
+    KURL u2 = d->baseURL;
+    QuantaCommon::setUrl(u2, el.attribute("url"));
+    if (!contains(u2))
+    {
+      el.parentNode().removeChild(el);
+    }
+  }
+}
 
+void Project::saveCursorPosition(const KURL &url, KTextEditor::ViewCursorInterface *viewCursorIf)
+{
+  if (!viewCursorIf || !hasProject() || !contains(url))
+    return;
+  QDomNodeList nl = d->m_sessionDom.elementsByTagName("item");
+  QDomElement el;
+  KURL u = QExtFileInfo::toRelative(url, d->baseURL);
+  uint line, col;
+  viewCursorIf->cursorPosition(&line, &col);
+  bool found = false;
+  for ( uint i = 0; i < nl.count(); i++ )
+  {
+    el = nl.item(i).toElement();
+    if ( el.attribute("url") == QuantaCommon::qUrl(u) )
+    {
+      el.setAttribute("line", line);
+      el.setAttribute("column", col);
+      found = true;
+      break;
+    }
+  }
+  if (!found)
+  {
+    el = d->m_sessionDom.createElement("item");
+    el.setAttribute("column", col);
+    el.setAttribute("line", line);
+    el.setAttribute("url", QuantaCommon::qUrl(u));
+    QDomNode no = d->m_sessionDom.firstChild().firstChild().namedItem("itemcursorpositions");
+    no.appendChild(el);   
+  }
+}
 #include "project.moc"
