@@ -49,6 +49,7 @@
 #include <kpassdlg.h>
 #include <kpushbutton.h>
 #include <ktempfile.h>
+#include <kuser.h>
 
 //standard includes
 #include <time.h>
@@ -61,14 +62,14 @@
 #include "qextfileinfo.h"
 #include "resource.h"
 
-ProjectUpload::ProjectUpload(const KURL& url, bool showOnlyProfiles, bool quickUpload, const char* name)
+ProjectUpload::ProjectUpload(const KURL& url, const QString& profileName, bool showOnlyProfiles, bool quickUpload, bool markOnly, const char* name)
   :ProjectUploadS( 0L, name, false, Qt::WDestructiveClose)
 {
     m_quickUpload = quickUpload;
     m_profilesOnly = showOnlyProfiles;
     list->hide();
     m_project = Project::ref();
-    initProjectInfo();
+    initProjectInfo(profileName);
     startUrl = url;
     if (m_profilesOnly)
     {
@@ -80,6 +81,8 @@ ProjectUpload::ProjectUpload(const KURL& url, bool showOnlyProfiles, bool quickU
       setCaption(i18n("Upload Profiles"));
     } else
     {
+      if (markOnly)
+        markAsUploaded->setChecked(true);
       QTimer::singleShot(10, this, SLOT(slotBuildTree()));
       currentItem = 0L;
     }
@@ -92,12 +95,12 @@ ProjectUpload::~ProjectUpload()
   delete baseUrl;
 }
 
-void  ProjectUpload::initProjectInfo()
+void  ProjectUpload::initProjectInfo(const QString& defaultProfile)
 {
   baseUrl = new KURL();
 
 //  list->setMultiSelection(true);
-  QDomDocument *dom = m_project->dom();
+  QDomDocument *dom = m_project->sessionDom();
   m_profilesNode = dom->firstChild().firstChild().namedItem("uploadprofiles");
   if (m_profilesNode.isNull()) //compat code, remove when upgrade from 3.2 is not supported
   {
@@ -121,7 +124,10 @@ void  ProjectUpload::initProjectInfo()
      m_project->setModified(true);
   } else
   {
-      m_defaultProfile = m_profilesNode.toElement().attribute("defaultProfile");
+      if (defaultProfile.isEmpty())
+        m_defaultProfile = m_profilesNode.toElement().attribute("defaultProfile");
+      else
+        m_defaultProfile = defaultProfile;
       QDomNodeList profileList = m_profilesNode.toElement().elementsByTagName("profile");
       QDomElement e;
       QString s;
@@ -149,6 +155,7 @@ void  ProjectUpload::initProjectInfo()
 /** No descriptions */
 void ProjectUpload::slotBuildTree()
 {
+ emit eventHappened("upload_requested", m_project->projectBaseURL().url(), "");
  loadRemoteUploadInfo();
  KIO::UDSEntry entry;
  QString strUrl = QuantaCommon::qUrl(startUrl);
@@ -170,7 +177,7 @@ void ProjectUpload::slotBuildTree()
 
  if (startUrl.isEmpty() || strUrl.endsWith("/")) //upload a folder 
  {
-   projectDirFiles = QExtFileInfo::allFilesDetailed(u, "*");
+   projectDirFiles = QExtFileInfo::allFilesDetailed(u, "*", this);
  } else
  {
    projectDirFiles.insert(u.url(), new KFileItem(KFileItem::Unknown, KFileItem::Unknown, u, true));
@@ -367,7 +374,7 @@ void ProjectUpload::startUpload()
     buttonUpload->setEnabled(false);
     KURL u = *baseUrl;
     u.setPath(u.protocol() == "file" ? "/" : "");
-    if (QExtFileInfo::exists(u))
+    if (QExtFileInfo::exists(u, false, this))
     {
       upload();
       return;
@@ -430,11 +437,12 @@ void ProjectUpload::upload()
       if ( !madeDirs.contains(dir) )
       {
         madeDirs.append( dir );
-        if (!QExtFileInfo::createDir(dir))
+        if (!QExtFileInfo::createDir(dir, this))
         {
           QuantaCommon::dirCreationError(this, KURL( dir.prettyURL(0, KURL::StripFileProtocol) ));
           buttonUpload->setEnabled(true);
           uploadInProgress = false;
+          saveRemoteUploadInfo();
           return;
         }
       }
@@ -476,6 +484,7 @@ void ProjectUpload::uploadFinished( KIO::Job *job )
       job->showErrorDialog( this  );
       uploadInProgress = false;
       buttonUpload->setEnabled(true);
+      saveRemoteUploadInfo();
       return;
    }
    KIO::FileCopyJob *fJob = dynamic_cast<KIO::FileCopyJob *>(job);
@@ -548,8 +557,11 @@ void ProjectUpload::slotUploadNext()
    // QListViewItem *it = list->findItem( currentURL.path() );
     QListViewItem *it = currentItem;
     if (it)
-    {
+    {      
      it->setSelected(false);
+     UploadTreeFile *itf = dynamic_cast<UploadTreeFile*>(it);
+     if (itf)
+      itf->setWhichPixmap( "check_clear" );
      it->repaint();
     }
     toUpload.remove( it );
@@ -625,8 +637,8 @@ void ProjectUpload::slotRemoveProfile()
    } else
    {
       QString profileName = comboProfile->currentText();
-      if (KMessageBox::warningYesNo(this, i18n("<qt>Do you really want to remove the <b>%1</b> upload profile?</qt>").arg(profileName),
-                                   i18n("Profile Removal")) == KMessageBox::Yes)
+      if (KMessageBox::warningContinueCancel(this, i18n("<qt>Do you really want to remove the <b>%1</b> upload profile?</qt>").arg(profileName),
+                                   i18n("Profile Removal"), KStdGuiItem::del()) == KMessageBox::Continue)
        {
           m_profilesNode.removeChild(m_currentProfileElement);
           int idx = comboProfile->currentItem();
@@ -689,10 +701,16 @@ void ProjectUpload::fillProfileDlg(UploadProfileDlgS *profileDlg)
 
 void ProjectUpload::readProfileDlg(UploadProfileDlgS *profileDlg)
 {
+  QString path = profileDlg->linePath->text();
+  if (path.startsWith("~/"))
+  {
+    KUser user;
+    path = user.homeDir() + path.mid(1);
+  }
   m_currentProfileElement.setAttribute("name", profileDlg->lineProfileName->text());
   m_currentProfileElement.setAttribute("remote_host", profileDlg->lineHost->text());
   m_currentProfileElement.setAttribute("user", profileDlg->lineUser->text());
-  m_currentProfileElement.setAttribute("remote_path", profileDlg->linePath->text());
+  m_currentProfileElement.setAttribute("remote_path", path);
   m_currentProfileElement.setAttribute("remote_port", profileDlg->port->text());
   m_currentProfileElement.setAttribute("remote_protocol", profileDlg->comboProtocol->currentText());
   QString passwd = QString(profileDlg->linePasswd->password());
@@ -737,8 +755,8 @@ void ProjectUpload::reject()
   if (uploadInProgress && !m_profilesOnly)
   {
     suspendUpload = true;
-    if (KMessageBox::questionYesNo(this,i18n("Do you really want to cancel the upload?"),
-                                   i18n("Cancel Upload")) == KMessageBox::No)
+    if (KMessageBox::questionYesNo(this,i18n("Do you really want to abort the upload?"),
+                                   i18n("Abort Upload"), i18n("Abort"), KStdGuiItem::cancel()) == KMessageBox::No)
     {
       suspendUpload = false;
       emit uploadNext();
