@@ -19,7 +19,7 @@
 #define QUANTA_H
 
 #define QUANTA_PACKAGE "quanta"
-#define QUANTA_VERSION "3.5.1"
+#define QUANTA_VERSION "3.5.2"
 
 #define IDS_STATUS      1
 #define IDS_INS_OVR     2
@@ -162,7 +162,7 @@ public:
   QString urlWithPreviewPrefix(const QString &url);
   void addFileToProject(const QString &url);
   void addFolderToProject(const QString &url);
-  /** Capture DCOP signals from KXsldbgPart or similar plugin */
+  void uploadURL(const QString &url, const QString& profile, bool markOnly);  /** Capture DCOP signals from KXsldbgPart or similar plugin */
   void newCursorPosition(const QString &file, int lineNumber, int columnNumber);
   void newDebuggerPosition(const QString &file, int lineNumber);
   void openFile(const QString &file, int lineNumber, int columnNumber);
@@ -217,6 +217,9 @@ public:
   void insertTagActionPoolItem(QString const& action_item);
   void removeTagActionPoolItem(QString const& action_item);
   void removeAllTagActionPoolItems() {m_tagActionPool.clear();}
+  /** Updates the structure and attribute treeview. */
+  void updateTreeViews();
+  void setTitle(const QString&);
   
   QPtrList<TagAction> const& tagActions() const {return m_tagActions;}
 
@@ -306,8 +309,9 @@ public slots:
   void slotContextMenuAboutToShow();
 
   /** options slots */
+  void slotShowMenuBar();
   void slotPreviewOptions();
-  void slotOptions();
+  void slotOptions(); 
   void slotOptionsConfigureKeys();
   void slotOptionsConfigureToolbars();
   void slotNewToolbarConfig();
@@ -426,7 +430,7 @@ public slots:
 
   // Get saved position of dock
   KDockWidget::DockPosition prevDockPosition(QWidget* dock, KDockWidget::DockPosition def);
-  
+ 
 protected slots:
   void slotDockWidgetHasUndocked(KDockWidget *widget);
   void slotPreviewBeingClosed();
@@ -543,13 +547,13 @@ protected:
   bool saveToolbar(bool localToolbar = true, const QString& toolbarToSave = QString::null, const KURL& destURL = KURL());
   /** Saves the toolbar and the actions. Returns the name of the actions file*/
   KURL saveToolbarToFile(const QString& toolbarName,const KURL& destFile);
-  void setTitle(const QString&);
-  /** Updates the structure and attribute treeview. */
-  void updateTreeViews();
   /** Makes the tabwidget look and behave like we want. If closeButtonsOnly is true,
   only the close button behavior is changed. */
   void initTabWidget(bool closeButtonsOnly = false);
 
+  void dropEvent(QDropEvent *ev);
+  void dragEnterEvent ( QDragEnterEvent * );
+
   void resetDockLayout();
 
   ScriptTreeView *scriptTab;
